@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::SV::Suc;
 use strict;
 use warnings;
-our $VERSION = '2.035';
+our $VERSION = '2.036';
 
 use utf8;
 use open ':utf8';
@@ -82,7 +82,7 @@ sub _create_atoms
             'MAD' => ['pos' => 'punc', 'punctype' => 'peri|qest|excl|colo'],
             # punctuation inside of sentence / interpunktion
             # examples: , - : * ;
-            'MID' => ['pos' => 'punc', 'punctype' => 'comm|dash|semi|colo'],
+            'MID' => ['pos' => 'punc', 'punctype' => 'comm|dash|semi'], # or 'colo'; but we do not want a conflict with 'MAD'
             # noun / substantiv
             # examples: år, arbete, barn, sätt, äktenskap
             'NN' => ['pos' => 'noun', 'nountype' => 'com'],
@@ -598,7 +598,7 @@ Lingua::Interset::Tagset::SV::Suc - Driver for the Swedish tagset of the Stockho
 
 =head1 VERSION
 
-version 2.035
+version 2.036
 
 =head1 SYNOPSIS
 
